==> mobGameSDK-5.0.2-sources.jar: com/mobgame/api/UploadListBitmapTask.java <==
package com.mobgame.api;

import android.app.Activity;
import android.content.Intent;
import android.graphics.Bitmap;
import android.os.AsyncTask;
import android.support.v4.content.LocalBroadcastManager;
import android.util.Log;

import com.game.sdk.comon.config.AuthenConfigs;
import com.game.sdk.comon.config.GameConfigs;
import com.game.sdk.comon.utils.LogUtils;
import com.mobgame.utils.Constants;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.ArrayList;

public class UploadListBitmapTask extends AsyncTask<Void, Void, Void> {

    private String TAG = "UploadBitmapTask";
    private String url;
    private ArrayList<Bitmap> listBitmap;
    private Callback callback;
    private Activity activity;
//
    public UploadListBitmapTask(Activity activity, String url, ArrayList<Bitmap> listBitmap) {
        this.url = url;
        this.listBitmap = listBitmap;
        this.activity = activity;
    }

    public UploadListBitmapTask(String url, ArrayList<Bitmap> listBitmap, Callback callback) {
        this.url = url;
        this.listBitmap = listBitmap;
        this.callback = callback;
    }

    public void setCallback(Callback callback) {
        this.callback = callback;
    }

    @Override
    protected Void doInBackground(Void... params) {

        HttpURLConnection conn = null;
        OutputStream outputStream = null;
        String boundary = "*****";
        String lineEnd = "\r\n";
        String twoHyphens = "--";
        long timestamp = System.currentTimeMillis() / 1000;
        String fileName = "IMG_" + timestamp + ".JPG";
        try {
            URL serverUrl = new URL(url);
            String result = "";
            for(int i=0; i<listBitmap.size(); i++){
                result = "";
                conn = (HttpURLConnection) serverUrl.openConnection();
                conn.setDoInput(true);
                conn.setDoOutput(true);
                conn.setUseCaches(false);
                conn.setRequestMethod("POST");
                conn.setRequestProperty("Connection", "Keep-Alive");
                conn.setRequestProperty("Content-Type", "multipart/form-data;boundary=" + boundary);
                conn.setRequestProperty(Constants.MOBGAME_TOKEN, AuthenConfigs.getInstance().getAccessToken());
                conn.setRequestProperty(Constants.MOBGAME_APPKEY, GameConfigs.getInstance().getAppKey());

                ByteArrayOutputStream
                        stream = new ByteArrayOutputStream();
                listBitmap.get(i).compress(Bitmap.CompressFormat.PNG, 100, stream);
                byte[] byteArray = stream.toByteArray();

                outputStream = conn.getOutputStream();
                outputStream.write((twoHyphens + boundary + lineEnd).getBytes());
                outputStream.write(("Content-Disposition: form-data; filename=\""
                        + fileName + "\"" + lineEnd).getBytes());
                outputStream.write(lineEnd.getBytes());
                outputStream.write(byteArray);
                outputStream.write(lineEnd.getBytes());
                outputStream.write((twoHyphens + boundary + twoHyphens + lineEnd).getBytes());

                InputStream is = conn.getInputStream();
                byte[] buffer = new byte[1024];

                while (is.read(buffer) >= 0) {
                    result += new String(buffer, "UTF-8");
                }
                result = result.replaceAll("\u0000.*", "");

            }
            if (activity != null && result != null) {
                Intent intent = new Intent("UploadBitmap");
                intent.putExtra("result", result);
                LocalBroadcastManager.getInstance(activity.getApplicationContext()).sendBroadcast(intent);
            }
            LogUtils.d(TAG, "doInBackground: result " + result);

            if (callback != null) {
                callback.onSuccess(conn.getResponseCode(), result);
                LogUtils.d(TAG, "doInBackground: getResponseCode: " + conn.getResponseCode());
                LogUtils.d(TAG, "doInBackground: getResponseMessage: " + conn.getResponseMessage());
            }

        } catch (Exception e) {
            e.printStackTrace();
            if (callback != null) {
                callback.onFailure(e);
            }
        } finally {
            try {
                if (outputStream != null) {
                    outputStream.flush();
                    outputStream.close();
                }
            } catch (IOException e) {
                e.printStackTrace();
                if (callback != null) {
                    callback.onFailure(e);
                }
            }
            if (conn != null) {
                conn.disconnect();
            }
        }
        return null;
    }


    public interface Callback {
        public void onSuccess(int code, String response);

        public void onFailure(Throwable e);
    }

}

==> mobGameSDK-5.3.3-sources.jar: com/mobgame/api/UploadListBitmapTask.java <==
package com.mobgame.api;

import android.app.Activity;
import android.content.Intent;
import android.graphics.Bitmap;
import android.os.AsyncTask;
import androidx.localbroadcastmanager.content.LocalBroadcastManager;

import com.game.sdk.comon.config.AuthenConfigs;
import com.game.sdk.comon.config.GameConfigs;
import com.game.sdk.comon.utils.LogUtils;
import com.mobgame.utils.Constants;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.ArrayList;

public class UploadListBitmapTask extends AsyncTask<Void, Void, Void> {

    private String TAG = "UploadBitmapTask";
    private String url;
    private ArrayList<Bitmap> listBitmap;
    private Callback callback;
    private Activity activity;
//
    public UploadListBitmapTask(Activity activity, String url, ArrayList<Bitmap> listBitmap) {
        this.url = url;
        this.listBitmap = listBitmap;
        this.activity = activity;
    }

    public void setCallback(Callback callback) {
        this.callback = callback;
    }

    @Override
    protected Void doInBackground(Void... params) {

        HttpURLConnection conn = null;
        OutputStream outputStream = null;
        String boundary = "*****";
        String lineEnd = "\r\n";
        String twoHyphens = "--";
        long timestamp = System.currentTimeMillis() / 1000;
        String fileName = "IMG_" + timestamp + ".JPG";
        try {
            URL serverUrl = new URL(url);
            String result = "";
            for(int i=0; i<listBitmap.size(); i++){
                result = "";
                conn = (HttpURLConnection) serverUrl.openConnection();
                conn.setDoInput(true);
                conn.setDoOutput(true);
                conn.setUseCaches(false);
                conn.setRequestMethod("POST");
                conn.setRequestProperty("Connection", "Keep-Alive");
                conn.setRequestProperty("Content-Type", "multipart/form-data;boundary=" + boundary);
                conn.setRequestProperty(Constants.MOBGAME_TOKEN, AuthenConfigs.getInstance().getAccessToken());
                conn.setRequestProperty(Constants.MOBGAME_APPKEY, GameConfigs.getInstance().getAppKey());

                ByteArrayOutputStream
                        stream = new ByteArrayOutputStream();
                listBitmap.get(i).compress(Bitmap.CompressFormat.PNG, 100, stream);
                byte[] byteArray = stream.toByteArray();

                outputStream = conn.getOutputStream();
                outputStream.write((twoHyphens + boundary + lineEnd).getBytes());
                outputStream.write(("Content-Disposition: form-data; filename=\""
                        + fileName + "\"" + lineEnd).getBytes());
                outputStream.write(lineEnd.getBytes());
                outputStream.write(byteArray);
                outputStream.write(lineEnd.getBytes());
                outputStream.write((twoHyphens + boundary + twoHyphens + lineEnd).getBytes());

                InputStream is = conn.getInputStream();
                byte[] buffer = new byte[1024];

                while (is.read(buffer) >= 0) {
                    result += new String(buffer, "UTF-8");
                }
                result = result.replaceAll("\u0000.*", "");

            }
            if (activity != null && result != null) {
                Intent intent = new Intent("UploadBitmap");
                intent.putExtra("result", result);
                LocalBroadcastManager.getInstance(activity.getApplicationContext()).sendBroadcast(intent);
            }
            LogUtils.d(TAG, "doInBackground: result " + result);

            if (callback != null) {
                callback.onSuccess(conn.getResponseCode(), result);
                LogUtils.d(TAG, "doInBackground: getResponseCode: " + conn.getResponseCode());
                LogUtils.d(TAG, "doInBackground: getResponseMessage: " + conn.getResponseMessage());
            }

        } catch (Exception e) {
            e.printStackTrace();
            if (callback != null) {
                callback.onFailure(e);
            }
        } finally {
            try {
                if (outputStream != null) {
                    outputStream.flush();
                    outputStream.close();
                }
            } catch (IOException e) {
                e.printStackTrace();
                if (callback != null) {
                    callback.onFailure(e);
                }
            }
            if (conn != null) {
                conn.disconnect();
            }
        }
        return null;
    }


    public interface Callback {
        public void onSuccess(int code, String response);

        public void onFailure(Throwable e);
    }

}
